@@ -435,7 +435,6 @@ def test_scipy(name, forgive):
 
 
 # (dopri5, .2), (bs, .03) <-- works in boost 1.59
-@pytest.mark.slow
 @requires('sym', 'pyodeint')
 @pytest.mark.parametrize('method,forgive', zip(
     'rosenbrock4 dopri5 bs'.split(), (.2, .2, .04)))
@@ -464,7 +463,6 @@ def _gsl(tout, method, forgive):
     check(yout[-1, :], n, p, a, atol, rtol, forgive)
 
 
-@pytest.mark.veryslow
 @requires('sym', 'pygslodeiv2')
 @pytest.mark.parametrize('method,forgive', zip(
     'msadams msbdf rkck bsimp'.split(), (5, 14, 0.2, 0.02)))
@@ -472,7 +470,6 @@ def test_gsl_predefined(method, forgive):
     _gsl([10**i for i in range(-14, 1)], method, forgive)
 
 
-@pytest.mark.veryslow
 @requires('sym', 'pygslodeiv2')
 @pytest.mark.parametrize('method,forgive', zip(
     'bsimp msadams msbdf rkck'.split(), (0.01, 4, 14, 0.21)))
@@ -492,7 +489,6 @@ def _cvode(tout, method, forgive):
     check(yout[-1, :], n, p, a, atol, rtol, forgive)
 
 
-@pytest.mark.slow
 @requires('sym', 'pycvodes')
 @pytest.mark.parametrize('method,forgive', zip(
     'adams bdf'.split(), (2.4, 5.0)))
@@ -501,7 +497,6 @@ def test_cvode_predefined(method, forgive):
 
 
 # cvode performs significantly better than vode:
-@pytest.mark.slow
 @requires('sym', 'pycvodes')
 @pytest.mark.parametrize('method,forgive', zip(
     'adams bdf'.split(), (2.4, 5)))
@@ -509,7 +504,6 @@ def test_cvode_adaptive(method, forgive):
     _cvode(1, method, forgive)
 
 
-@pytest.mark.veryslow
 @requires('sym', 'scipy')
 @pytest.mark.parametrize('n,forgive', [(4, 1), (17, 1), (42, 7)])
 def test_long_chain_dense(n, forgive):
@@ -522,7 +516,6 @@ def test_long_chain_dense(n, forgive):
     check(yout[-1, :], n, p, a, atol, rtol, forgive)
 
 
-@pytest.mark.slow
 @requires('sym', 'scipy')
 @pytest.mark.parametrize('n', [29])  # something maxes out at 31
 def test_long_chain_banded_scipy(n):
@@ -554,7 +547,6 @@ def test_long_chain_banded_scipy(n):
     assert min_time_dens*2 > min_time_band  # (2x: fails sometimes due to load)
 
 
-@pytest.mark.veryslow
 @requires('sym', 'pycvodes')
 @pytest.mark.parametrize('n', [29, 79])
 def test_long_chain_banded_cvode(n):
@@ -584,7 +576,6 @@ def test_long_chain_banded_cvode(n):
         pass  # will fail sometimes due to load
 
 
-@pytest.mark.slow
 @requires('sym', 'pycvodes', 'pygslodeiv2')
 @pytest.mark.parametrize('integrator', ['cvode', 'gsl'])
 def test_no_diff_adaptive_auto_switch_single(integrator):
@@ -603,7 +594,6 @@ def test_no_diff_adaptive_auto_switch_single(integrator):
     assert np.allclose(yout2, ref)
 
 
-@pytest.mark.slow
 @requires('sym', 'pycvodes', 'pygslodeiv2')
 @pytest.mark.parametrize('integrator', ['cvode', 'gsl'])
 def test_no_diff_adaptive_auto_switch_single__multimode(integrator):
@@ -706,7 +696,6 @@ def test_PartiallySolvedSystem__using_y(integrator):
     assert np.allclose(np.sum(yout, axis=1), sum(y0))
 
 
-@pytest.mark.slow
 @requires('sym', 'pycvodes', 'pygslodeiv2')
 @pytest.mark.parametrize('integrator', ['cvode', 'gsl'])
 def test_PartiallySolvedSystem_multiple_subs(integrator):
@@ -763,7 +752,6 @@ def _get_transf_part_system():
     return LogLogSys.from_other(partsys)
 
 
-@pytest.mark.slow
 @requires('sym', 'pycvodes', 'pygslodeiv2')
 @pytest.mark.parametrize('integrator', ['cvode', 'gsl'])
 def test_PartiallySolvedSystem__symmetricsys(integrator):
@@ -777,7 +765,6 @@ def test_PartiallySolvedSystem__symmetricsys(integrator):
     assert np.allclose(np.sum(yout, axis=1), sum(y0))
 
 
-@pytest.mark.slow
 @requires('sym', 'pycvodes', 'pygslodeiv2')
 @pytest.mark.parametrize('integrator', ['cvode', 'gsl'])
 def test_PartiallySolvedSystem__symmetricsys__multi(integrator):
@@ -824,7 +811,6 @@ def _ref_nonlin(y0, k, t):
     return (x4*x8 + x5*x8 + x7*(x2 + x6))/(2*kf*(x6 + x7))
 
 
-@pytest.mark.slow
 @requires('sym', 'pycvodes', 'pygslodeiv2')
 @pytest.mark.parametrize('integrator', ['cvode', 'gsl'])
 def test_PartiallySolvedSystem__symmetricsys__nonlinear(integrator):
@@ -917,7 +903,6 @@ def test_SymbolicSys_from_callback__symcxx():
     _test_SymbolicSys_from_callback__backend('symcxx')
 
 
-@pytest.mark.slow
 @requires('sym', 'pycvodes', 'pygslodeiv2')
 @pytest.mark.parametrize('integrator,method', [('cvode', 'adams'), ('gsl', 'msadams')])
 def test_integrate_auto_switch(integrator, method):
@@ -984,7 +969,6 @@ def _test_cetsa(y0, params, extra=False, stepx=1, **kwargs):
         assert tres.info['nfev'] > 100
 
 
-@pytest.mark.veryslow
 @requires('sym', 'pycvodes', 'pygslodeiv2', 'pyodeint')
 @pytest.mark.parametrize('integrator', ['cvode', 'gsl', 'odeint'])
 def test_cetsa(integrator):
@@ -994,7 +978,6 @@ def test_cetsa(integrator):
         _test_cetsa(_cetsa.ys[0], _cetsa.ps[0], extra=True, integrator=integrator)
 
 
-@pytest.mark.veryslow
 @requires('sym', 'pycvodes', 'pygslodeiv2', 'pyodeint')
 @pytest.mark.parametrize('integrator', ['cvode', 'gsl', 'odeint'])
 def test_cetsa_multi(integrator):
@@ -1075,7 +1058,6 @@ def test_SymbolicSys__first_step_expr():
     assert np.allclose(yout, ref, atol=10*kwargs['atol'], rtol=10*kwargs['rtol'])
 
 
-@pytest.mark.slow
 @requires('sym', 'pygslodeiv2')
 def test_SymbolicSys__from_callback__first_step_expr():
     tend, k, y0 = 5, [1e23, 3], (.7, .0, .0)
@@ -1243,7 +1225,6 @@ def test_SymbolicSys__reference_parameters_using_symbols_from_callback(method):
                 assert np.allclose(yout[:, 0], 2*np.exp(-3*xout))
 
 
-@pytest.mark.slow
 @requires('sym', 'pycvodes')
 @pytest.mark.parametrize('scaled', [False, True])
 def test_PartiallySolvedSystem__from_linear_invariants(scaled):
@@ -1343,7 +1324,6 @@ def test_PartiallySolvedSystem__roots(idx):
     check(psys)
 
 
-@pytest.mark.slow
 @requires('sym', 'pycvodes')
 @pytest.mark.parametrize('idx1,idx2,scaled,b2', product([0, 1, 2], [0, 1, 2], [True, False], [None, 0]))
 def test_TransformedSys__roots(idx1, idx2, scaled, b2):
